==> kadaster-gds2-2.4-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20170401/BestandenLijstType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for BestandenLijstType complex type.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * 
 * &lt;pre&gt;
 * &amp;lt;complexType name="BestandenLijstType"&amp;gt;
 *   &amp;lt;complexContent&amp;gt;
 *     &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&amp;gt;
 *       &amp;lt;sequence&amp;gt;
 *         &amp;lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401}Afgifte" maxOccurs="unbounded"/&amp;gt;
 *       &amp;lt;/sequence&amp;gt;
 *     &amp;lt;/restriction&amp;gt;
 *   &amp;lt;/complexContent&amp;gt;
 * &amp;lt;/complexType&amp;gt;
 * &lt;/pre&gt;
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenLijstType", propOrder = {
    "afgifte"
})
public class BestandenLijstType {

    @XmlElement(name = "Afgifte", required = true)
    protected List<AfgifteType> afgifte;

    /**
     * Gets the value of the afgifte property.
     * 
     * &lt;p&gt;
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a &lt;CODE&gt;set&lt;/CODE&gt; method for the afgifte property.
     * 
     * &lt;p&gt;
     * For example, to add a new item, do as follows:
     * &lt;pre&gt;
     *    getAfgifte().add(newItem);
     * &lt;/pre&gt;
     * 
     * 
     * &lt;p&gt;
     * Objects of the following type(s) are allowed in the list
     * {@link AfgifteType }
     * 
     * 
     */
    public List<AfgifteType> getAfgifte() {
        if (afgifte == null) {
            afgifte = new ArrayList<AfgifteType>();
        }
        return this.afgifte;
    }

}

==> kadaster-gds2-3.1-sources.jar: nl/kadaster/schemas/gds2/afgifte_bestandenlijstresultaat/afgifte/v20170401/BestandenLijstType.java <==

package nl.kadaster.schemas.gds2.afgifte_bestandenlijstresultaat.afgifte.v20170401;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for BestandenLijstType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="BestandenLijstType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element ref="{http://www.kadaster.nl/schemas/gds2/afgifte-bestandenlijstresultaat/afgifte/v20170401}Afgifte" maxOccurs="unbounded"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "BestandenLijstType", propOrder = {
    "afgifte"
})
public class BestandenLijstType {

    @XmlElement(name = "Afgifte", required = true)
    protected List<AfgifteType> afgifte;

    /**
     * Gets the value of the afgifte property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the afgifte property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getAfgifte().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link AfgifteType }
     * 
     * 
     */
    public List<AfgifteType> getAfgifte() {
        if (afgifte == null) {
            afgifte = new ArrayList<AfgifteType>();
        }
        return this.afgifte;
    }

}
